@@ -143,9 +143,10 @@ COLUMNS = {
     "origin": ["url"],
     "origin_visit": ["visit", "type", ("origin.url", "origin"), "date",],
     "origin_visit_status": [
-        "visit",
+        ("origin_visit_status.visit", "visit"),
         ("origin.url", "origin"),
-        "date",
+        ("origin_visit_status.date", "date"),
+        ("origin_visit.type", "type"),
         "snapshot",
         "status",
         "metadata",
@@ -160,7 +161,13 @@ JOINS = {
         "person c on revision.committer=c.id",
     ],
     "origin_visit": ["origin on origin_visit.origin=origin.id"],
-    "origin_visit_status": ["origin on origin_visit_status.origin=origin.id"],
+    "origin_visit_status": [
+        "origin on origin_visit_status.origin=origin.id",
+        # Joining on origin_visit to be able to  backfill before the
+        # origin_visit_status.type is populated by a migration script
+        # TODO remove this when origin_visit_status.type is fully populated
+        "origin_visit using (origin, visit)",
+    ],
     "raw_extrinsic_metadata": [
         "metadata_authority on "
         "raw_extrinsic_metadata.authority_id=metadata_authority.id",
@@ -504,7 +511,7 @@ class JournalBackfiller:
                 % (object_type, ", ".join(COLUMNS.keys()))
             )
 
-        if object_type in ["origin", "origin_visit"]:
+        if object_type in ["origin", "origin_visit", "origin_visit_status"]:
             if start_object:
                 start_object = int(start_object)
             else:
