@@ -9,7 +9,18 @@ import itertools
 import json
 import random
 import re
-from typing import Any, Callable, Dict, Iterable, List, Optional, Set, Tuple, Union
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Iterable,
+    List,
+    Optional,
+    Sequence,
+    Set,
+    Tuple,
+    Union,
+)
 
 import attr
 
@@ -292,7 +303,7 @@ class CassandraStorage:
         self, contents: List[Sha1Git]
     ) -> Iterable[Sha1Git]:
         return self.content_missing(
-            [{"sha1_git": c for c in contents}], key_hash="sha1_git"
+            [{"sha1_git": c} for c in contents], key_hash="sha1_git"
         )
 
     def content_get_random(self) -> Sha1Git:
@@ -877,6 +888,7 @@ class CassandraStorage:
                     origin=visit.origin,
                     visit=visit.visit,
                     date=visit.date,
+                    type=visit.type,
                     status="created",
                     snapshot=None,
                 )
@@ -886,6 +898,14 @@ class CassandraStorage:
 
     def _origin_visit_status_add(self, visit_status: OriginVisitStatus) -> None:
         """Add an origin visit status"""
+        if visit_status.type is None:
+            origin_row = self._cql_runner.origin_visit_get_one(
+                visit_status.origin, visit_status.visit
+            )
+            if origin_row is None:
+                raise StorageArgumentException(f"Unknown origin {visit_status.origin}")
+            visit_status = attr.evolve(visit_status, type=origin_row.type)
+
         self.journal_writer.origin_visit_status_add([visit_status])
         self._cql_runner.origin_visit_status_add_one(
             converters.visit_status_to_row(visit_status)
@@ -918,6 +938,9 @@ class CassandraStorage:
             "origin": visit["origin"],
             # but keep the date of the creation of the origin visit
             "date": visit["date"],
+            # We use the visit type from origin visit
+            # if it's not present on the origin visit status
+            "type": visit_status.type or visit["type"],
         }
 
     def _origin_visit_get_latest_status(self, visit: OriginVisit) -> OriginVisitStatus:
@@ -1137,7 +1160,7 @@ class CassandraStorage:
             try:
                 row = RawExtrinsicMetadataRow(
                     type=metadata_entry.type.value,
-                    id=str(metadata_entry.id),
+                    target=str(metadata_entry.target),
                     authority_type=metadata_entry.authority.type.value,
                     authority_url=metadata_entry.authority.url,
                     discovery_date=metadata_entry.discovery_date,
@@ -1160,23 +1183,23 @@ class CassandraStorage:
     def raw_extrinsic_metadata_get(
         self,
         type: MetadataTargetType,
-        id: Union[str, SWHID],
+        target: Union[str, SWHID],
         authority: MetadataAuthority,
         after: Optional[datetime.datetime] = None,
         page_token: Optional[bytes] = None,
         limit: int = 1000,
     ) -> PagedResult[RawExtrinsicMetadata]:
         if type == MetadataTargetType.ORIGIN:
-            if isinstance(id, SWHID):
+            if isinstance(target, SWHID):
                 raise StorageArgumentException(
                     f"raw_extrinsic_metadata_get called with type='origin', "
-                    f"but provided id is an SWHID: {id!r}"
+                    f"but provided target is a SWHID: {target!r}"
                 )
         else:
-            if not isinstance(id, SWHID):
+            if not isinstance(target, SWHID):
                 raise StorageArgumentException(
                     f"raw_extrinsic_metadata_get called with type!='origin', "
-                    f"but provided id is not an SWHID: {id!r}"
+                    f"but provided target is not a SWHID: {target!r}"
                 )
 
         if page_token is not None:
@@ -1188,7 +1211,7 @@ class CassandraStorage:
                     "page_token is inconsistent with the value of 'after'."
                 )
             entries = self._cql_runner.raw_extrinsic_metadata_get_after_date_and_fetcher(  # noqa
-                str(id),
+                str(target),
                 authority.type.value,
                 authority.url,
                 after_date,
@@ -1197,11 +1220,11 @@ class CassandraStorage:
             )
         elif after is not None:
             entries = self._cql_runner.raw_extrinsic_metadata_get_after_date(
-                str(id), authority.type.value, authority.url, after
+                str(target), authority.type.value, authority.url, after
             )
         else:
             entries = self._cql_runner.raw_extrinsic_metadata_get(
-                str(id), authority.type.value, authority.url
+                str(target), authority.type.value, authority.url
             )
 
         if limit:
@@ -1211,11 +1234,11 @@ class CassandraStorage:
         for entry in entries:
             discovery_date = entry.discovery_date.replace(tzinfo=datetime.timezone.utc)
 
-            assert str(id) == entry.id
+            assert str(target) == entry.target
 
             result = RawExtrinsicMetadata(
                 type=MetadataTargetType(entry.type),
-                id=id,
+                target=target,
                 authority=MetadataAuthority(
                     type=MetadataAuthorityType(entry.authority_type),
                     url=entry.authority_url,
@@ -1303,11 +1326,11 @@ class CassandraStorage:
         else:
             return None
 
-    def clear_buffers(self, object_types: Optional[List[str]] = None) -> None:
+    def clear_buffers(self, object_types: Sequence[str] = ()) -> None:
         """Do nothing
 
         """
         return None
 
-    def flush(self, object_types: Optional[List[str]] = None) -> Dict:
+    def flush(self, object_types: Sequence[str] = ()) -> Dict[str, int]:
         return {}
