@@ -9,7 +9,7 @@ import contextlib
 from contextlib import contextmanager
 import datetime
 import itertools
-from typing import Any, Counter, Dict, Iterable, List, Optional, Tuple, Union
+from typing import Any, Counter, Dict, Iterable, List, Optional, Sequence, Tuple, Union
 
 import attr
 import psycopg2
@@ -844,6 +844,7 @@ class Storage:
                 origin=visit.origin,
                 visit=visit.visit,
                 date=visit.date,
+                type=visit.type,
                 status="created",
                 snapshot=None,
             )
@@ -867,13 +868,27 @@ class Storage:
     def origin_visit_status_add(
         self, visit_statuses: List[OriginVisitStatus], db=None, cur=None,
     ) -> None:
+        visit_statuses_ = []
+
         # First round to check existence (fail early if any is ko)
         for visit_status in visit_statuses:
             origin_url = self.origin_get([visit_status.origin], db=db, cur=cur)[0]
             if not origin_url:
                 raise StorageArgumentException(f"Unknown origin {visit_status.origin}")
 
-        for visit_status in visit_statuses:
+            if visit_status.type is None:
+                origin_visit = self.origin_visit_get_by(
+                    visit_status.origin, visit_status.visit, db=db, cur=cur
+                )
+                assert origin_visit is not None
+
+                origin_visit_status = attr.evolve(visit_status, type=origin_visit.type)
+            else:
+                origin_visit_status = visit_status
+
+            visit_statuses_.append(origin_visit_status)
+
+        for visit_status in visit_statuses_:
             self._origin_visit_status_add(visit_status, db, cur)
 
     @timed
@@ -1036,6 +1051,7 @@ class Storage:
                     origin=row_d["origin"],
                     visit=row_d["visit"],
                     date=row_d["date"],
+                    type=row_d["type"],
                     status=row_d["status"],
                     snapshot=row_d["snapshot"],
                     metadata=row_d["metadata"],
@@ -1246,7 +1262,7 @@ class Storage:
 
             db.raw_extrinsic_metadata_add(
                 type=metadata_entry.type.value,
-                id=str(metadata_entry.id),
+                target=str(metadata_entry.target),
                 discovery_date=metadata_entry.discovery_date,
                 authority_id=authority_id,
                 fetcher_id=fetcher_id,
@@ -1274,7 +1290,7 @@ class Storage:
     def raw_extrinsic_metadata_get(
         self,
         type: MetadataTargetType,
-        id: Union[str, SWHID],
+        target: Union[str, SWHID],
         authority: MetadataAuthority,
         after: Optional[datetime.datetime] = None,
         page_token: Optional[bytes] = None,
@@ -1283,16 +1299,16 @@ class Storage:
         cur=None,
     ) -> PagedResult[RawExtrinsicMetadata]:
         if type == MetadataTargetType.ORIGIN:
-            if isinstance(id, SWHID):
+            if isinstance(target, SWHID):
                 raise StorageArgumentException(
                     f"raw_extrinsic_metadata_get called with type='origin', "
-                    f"but provided id is an SWHID: {id!r}"
+                    f"but provided target is a SWHID: {target!r}"
                 )
         else:
-            if not isinstance(id, SWHID):
+            if not isinstance(target, SWHID):
                 raise StorageArgumentException(
                     f"raw_extrinsic_metadata_get called with type!='origin', "
-                    f"but provided id is not an SWHID: {id!r}"
+                    f"but provided target is not a SWHID: {target!r}"
                 )
 
         if page_token:
@@ -1310,12 +1326,12 @@ class Storage:
             return PagedResult(next_page_token=None, results=[],)
 
         rows = db.raw_extrinsic_metadata_get(
-            type, str(id), authority_id, after_time, after_fetcher, limit + 1, cur,
+            type, str(target), authority_id, after_time, after_fetcher, limit + 1, cur,
         )
         rows = [dict(zip(db.raw_extrinsic_metadata_get_cols, row)) for row in rows]
         results = []
         for row in rows:
-            assert str(id) == row["raw_extrinsic_metadata.id"]
+            assert str(target) == row["raw_extrinsic_metadata.target"]
             results.append(converters.db_to_raw_extrinsic_metadata(row))
 
         if len(results) > limit:
@@ -1396,13 +1412,13 @@ class Storage:
             return None
         return MetadataAuthority.from_dict(dict(zip(db.metadata_authority_cols, row)))
 
-    def clear_buffers(self, object_types: Optional[List[str]] = None) -> None:
+    def clear_buffers(self, object_types: Sequence[str] = ()) -> None:
         """Do nothing
 
         """
         return None
 
-    def flush(self, object_types: Optional[List[str]] = None) -> Dict:
+    def flush(self, object_types: Sequence[str] = ()) -> Dict[str, int]:
         return {}
 
     def _get_authority_id(self, authority: MetadataAuthority, db, cur):
